import { format, parseISO } from "date-fns";
import { motion } from "framer-motion";
import Image from "next/image";
import { Category } from "payload-types";
import { Key } from "react";
import webConfig from "web.config";

import { animateOpacity, createImageUrl, joinClassNames, shorten } from "utils/helper";

import { Button } from "components/Button";
import { Heading } from "components/Heading";

type Props = {
  data: any;
  index: number;
  length: number;
};

const Article = ({ data }: Props) => {
  const href = `/blog/${data.slug}`;

  return (
    <div>
      <motion.div className={joinClassNames("py-8")} {...animateOpacity}>
        <div className="relative h-[14rem] lg:h-[22rem]">
          {data.image && (
            <Image
              src={createImageUrl(data.image.url)}
              alt={data.image.alt}
              className="object-cover rounded"
              fill
            />
          )}
        </div>
        <div className="flex flex-col justify-between items-start pt-8 lg:min-h-[25rem]">
          <div className="mb-8">
            <div className="flex space-x-2 mb-4">
              {data.categories?.map((item: Category, index: Key) => (
                <div
                  className="border border-primary-800 text-primary-800 px-4 py-2.5 rounded-sm font-display text-lg tracking-widest leading-none"
                  key={index}
                >
                  {item.title}
                </div>
              ))}
            </div>
            <div className="mb-2">
              <Heading type="h3" as="p" text={data.title} />
              {data.publishDate && (
                <p
                  className="text-gray-400 font-display text-lg tracking-wider"
                  suppressHydrationWarning
                >
                  {format(parseISO(data.publishDate), webConfig.dateFormat)}
                </p>
              )}
            </div>
            <p className="text-sm lg:text-base lg:w-3/4 text-justify text-gray-600">
              {shorten(data.excerpt, 250)}
            </p>
          </div>
          <Button
            size="base"
            style="primary"
            variant="primary"
            text="Číst více"
            link={{ url: href }}
          />
        </div>
      </motion.div>
    </div>
  );
};

export default Article;
