import { Post } from "payload-types";
import { useRef, useState } from "react";

import { MARGIN_BOTTOM } from "styles/constants";

import { joinClassNames, paginate } from "utils/helper";

import { Article } from "components/Article";
import { Pagination } from "components/Pagination";

type Props = {
  articles: Post[];
  perPage: number;
  id: string;
  margin: keyof typeof MARGIN_BOTTOM;
};

const Articles = ({ articles, perPage, margin }: Props) => {
  const ref = useRef(null);
  const [page, setPage] = useState(1);
  const { items, total, totalPages } = paginate(articles, page, perPage);

  const handlePageChange = (page) => {
    setPage(page);
    ref.current.scrollIntoView({ behavior: "smooth" });
  };

  return (
    <div className={joinClassNames(margin && MARGIN_BOTTOM[margin])} ref={ref}>
      <div className="grid grid-border grid-cols-1 lg:grid-cols-2 mb-8">
        {items.map((item, index) => (
          <Article data={item} index={index} length={items.length} key={index} />
        ))}
      </div>
      <Pagination
        page={page}
        handlePageChange={handlePageChange}
        totalPages={totalPages}
        total={total}
      />
    </div>
  );
};

export default Articles;
