import { EnvelopeIcon, PhoneIcon } from "@heroicons/react/24/solid";
import { GlobalContext } from "pages/_app";
import { useContext } from "react";

const Banner = () => {
  const { websiteSettings, contactDetails } = useContext(GlobalContext);
  if (!websiteSettings.enableBanner) {
    return null;
  }

  if (websiteSettings.style === "contact") {
    return (
      <div className="bg-primary-700 shadow">
        <div className="max-w-5xl px-4 lg:px-0 mx-auto py-2 sm:py-4 text-white font-display text-lg sm:text-xl tracking-wider flex sm:items-center sm:space-x-12 justify-between sm:justify-start">
          <div className="hidden sm:flex items-center">{contactDetails.companyName}</div>
          <a
            href={`mailto:${contactDetails.emailAddress}`}
            className="flex items-center hover:text-gray-200 transition-colors"
          >
            <EnvelopeIcon className="hidden sm:block w-3 lg:w-4 mr-2" />{" "}
            {contactDetails.emailAddress}
          </a>
          <a
            href={`tel:${contactDetails.telephoneNumber}`}
            className="flex items-center hover:text-gray-200 transition-colors"
          >
            <PhoneIcon className="hidden sm:block w-3 lg:w-4 mr-2" />{" "}
            {contactDetails.telephoneNumber}
          </a>
        </div>
      </div>
    );
  }

  return (
    <div className="bg-primary-700 shadow">
      <div className="max-w-5xl px-4 xl:px-0 mx-auto py-4 text-white font-display text-xl tracking-wider flex items-center">
        {websiteSettings.contentOfBanner}
      </div>
    </div>
  );
};

export default Banner;
