import Image from "next/image";

import { joinClassNames } from "utils/helper";

const ICON_SIZE = {
  sm: "h-6 lg:h-8",
  md: "h-10 lg:h-12 ",
  lg: "h-14 lg:h-16",
  xl: "h-16 lg:h-32",
};

const TYPE = {
  left: "/images/logo.svg",
  center: "/images/logo-center.svg",
};

type Props = {
  size: keyof typeof ICON_SIZE;
  className?: string;
  type?: keyof typeof TYPE;
};

const Brand = ({ size, className, type }: Props) => {
  return (
    <div className="relative inline-flex items-center">
      <Image
        src={TYPE[type ? type : "left"]}
        className={joinClassNames(ICON_SIZE[size], "w-full", className)}
        width="0"
        height="0"
        sizes="100vw"
        alt="Logo společnosti Energosavings"
      />
    </div>
  );
};

export default Brand;
