import Image from "next/image";
import Link from "next/link";
import { Media, Page, Post } from "payload-types";
import { Fragment } from "react";

import { createImageUrl, joinClassNames } from "utils/helper";

import { DEFAULT, ICON, SIZE, STYLE, VARIANT } from "components/Button";

type ButtonBlockType = Partial<
  Omit<Extract<Page["layout"][0], { blockType: "button" }>, "blockType" | "link">
> & {
  link?: any;
  [x: string]: any;
};

export default function Button({
  size,
  text,
  style,
  icon,
  variant,
  link,
  ...props
}: ButtonBlockType) {
  const Inner = () => {
    switch (variant) {
      case "primary":
        return (
          <Fragment>
            {icon && (
              <Image
                src={createImageUrl((icon as Media).url)}
                alt={(icon as Media).alt}
                width={(icon as Media).width}
                height={(icon as Media).height}
                className={joinClassNames(ICON[size])}
              />
            )}
            {text}
          </Fragment>
        );
      case "secondary":
        return (
          <Fragment>
            <span className="relative z-20">{text}</span>
            <span
              className={joinClassNames(
                "absolute inset-0 h-full w-0 transition-all group-hover:w-full",
                STYLE[variant ? variant : "primary"]["inner"][style]
              )}
            />
          </Fragment>
        );
      default:
        break;
    }
  };
  if (link) {
    return (
      <Link
        href={link?.type === "reference" ? (link.reference.value as Page | Post).slug : link.url}
        target={link.newTab ? "_blank" : "_self"}
        className={joinClassNames(
          DEFAULT,
          SIZE[size],
          STYLE[variant ? variant : "primary"][style],
          VARIANT[variant]
        )}
      >
        <Inner />
      </Link>
    );
  } else {
    return (
      <button
        className={joinClassNames(
          DEFAULT,
          SIZE[size],
          STYLE[variant ? variant : "primary"][style],
          VARIANT[variant]
        )}
        {...props}
      >
        <Inner />
      </button>
    );
  }
}
