import { Bars3Icon } from "@heroicons/react/24/solid";
import { GlobalContext } from "pages/_app";
import { useEffect, useRef, useState } from "react";
import { useContext } from "react";

import { joinClassNames } from "utils/helper";

import { Brand } from "components/Brand";
import { Menu } from "components/Menu";
import { Navigation } from "components/Navigation";
import { SocialLink } from "components/SocialLink";

const Header = () => {
  const { socials, header } = useContext(GlobalContext);
  const [scrolledOver, setScrolledOver] = useState(false);
  const [open, setOpen] = useState<boolean>(false);
  const headerRef = useRef<HTMLDivElement>();
  const secondRef = useRef<HTMLDivElement>();

  useEffect(() => {
    if (typeof window !== "undefined") {
      window.addEventListener("scroll", () => {
        const clientHeight = headerRef.current?.clientHeight;
        if (window.pageYOffset > clientHeight) {
          setScrolledOver(true);
        } else {
          setScrolledOver(false);
        }
      });
    }
  }, [headerRef]);

  const Social = () => (
    <div className="flex items-bottom space-x-4 ml-auto">
      {socials.showFacebook && (
        <SocialLink
          href={socials.facebookUrl}
          icon={{ src: "/icons/facebook.svg", alt: "Facebook" }}
          label="Facebook"
        />
      )}
      {socials.showInstagram && (
        <SocialLink
          href={socials.instagramUrl}
          icon={{ src: "/icons/instagram.svg", alt: "Instagram" }}
          label="Instagram"
        />
      )}
      {socials.showTwitter && (
        <SocialLink
          href={socials.twitterUrl}
          icon={{ src: "/icons/twitter.svg", alt: "Twitter" }}
          label="Twutter"
        />
      )}
      {socials.showLinkedIn && (
        <SocialLink
          href={socials.linkedInUrl}
          icon={{ src: "/icons/linkedin-in.svg", alt: "LinkedIn" }}
          label="LinkedIn"
        />
      )}
    </div>
  );

  return (
    <div className="relative mb-8 md:mb-16">
      <div className="hidden lg:block bg-primary-500" ref={headerRef}>
        <div className="max-w-5xl py-6 px-4 lg:px-0 mx-auto flex space-x-8 items-center justify-between">
          <Brand size="lg" />
          <div className="hidden lg:block">
            <Social />
          </div>
        </div>
      </div>
      {scrolledOver && <div style={{ height: secondRef.current.clientHeight }}></div>}
      <div
        className={joinClassNames(scrolledOver ? "fixed top-0 z-30 w-full" : "static")}
        ref={secondRef}
      >
        <div className="px-4 bg-primary-500">
          <div className="flex justify-between max-w-5xl py-4 mx-auto">
            <button className="block lg:hidden" onClick={() => setOpen(!open)}>
              <Bars3Icon className="h-8 w-8 text-white" />
            </button>
            <div className="block lg:hidden">
              <Social />
            </div>
            <Navigation items={header.items} />
            <Menu open={open} setOpen={setOpen} items={header.items} />
          </div>
        </div>
        <div className="bg-[url('/images/layered-waves-3-haikei.svg')] bg-cover h-2 lg:h-16"></div>
      </div>
    </div>
  );
};

export default Header;
