import { getCookie, setCookie } from "cookies-next";
import { useRouter } from "next/router";
import { useEffect, useState } from "react";

import { joinClassNames } from "utils/helper";

import { Button } from "components/Button";
import { Modal } from "components/Modal";

const PreviewBar = () => {
  const [modalOpen, setModalOpen] = useState<boolean>(false);
  const [hidePreviewBarStatus, setHidePreviewBarStatus] = useState<boolean>(undefined);
  const [cookieLoaded, setCookieLoaded] = useState<boolean>(false);
  const [routeChanging, setRouteChanging] = useState<boolean>(false);
  const router = useRouter();

  const hidePreviewBar = () => {
    setModalOpen(false);
    setCookie("hidePreviewBar", true);
    setHidePreviewBarStatus(true);
  };

  const startReload = () => {
    router.reload();
    setRouteChanging(true);
  };

  useEffect(() => {
    setHidePreviewBarStatus(getCookie("hidePreviewBar") as boolean);
    setCookieLoaded(true);
  }, []);

  return (
    <>
      <div className="fixed flex flex-col space-y-2 bottom-4 left-4 z-50">
        <button
          className="h-10 w-10 bg-primary-600 hover:bg-primary-700 transition-colors flex justify-center items-center shadow rounded"
          onClick={startReload}
        >
          <svg
            xmlns="http://www.w3.org/2000/svg"
            viewBox="0 0 512 512"
            className={joinClassNames("h-4", routeChanging && "animate-spin")}
            fill="#fff"
          >
            <path d="M447.5 224H456c13.3 0 24-10.7 24-24V72c0-9.7-5.8-18.5-14.8-22.2s-19.3-1.7-26.2 5.2L397.4 96.6c-87.6-86.5-228.7-86.2-315.8 1c-87.5 87.5-87.5 229.3 0 316.8s229.3 87.5 316.8 0c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0c-62.5 62.5-163.8 62.5-226.3 0s-62.5-163.8 0-226.3c62.2-62.2 162.7-62.5 225.3-1L311 183c-6.9 6.9-8.9 17.2-5.2 26.2s12.5 14.8 22.2 14.8H447.5z" />
          </svg>
        </button>
        <button
          className="h-10 w-10 bg-primary-600 hover:bg-primary-700 transition-colors flex justify-center items-center shadow rounded"
          onClick={() => setModalOpen(true)}
        >
          <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512" className="h-4" fill="#fff">
            <path d="M416 208c0 45.9-14.9 88.3-40 122.7L502.6 457.4c12.5 12.5 12.5 32.8 0 45.3s-32.8 12.5-45.3 0L330.7 376c-34.4 25.2-76.8 40-122.7 40C93.1 416 0 322.9 0 208S93.1 0 208 0S416 93.1 416 208zM208 352a144 144 0 1 0 0-288 144 144 0 1 0 0 288z" />
          </svg>
        </button>
      </div>
      <Modal
        isOpen={modalOpen || (hidePreviewBarStatus != true && cookieLoaded === true)}
        setIsOpen={setModalOpen}
        className="max-w-3xl"
        align="middle"
      >
        <Modal.Header>
          <Modal.Title>Náhled</Modal.Title>
        </Modal.Header>
        <Modal.Body>
          Webová stránka je otevřena v režimu náhledu. Režim náhledu umožňuje vidět nejnovější změny
          stránek v režimu konceptu. Funkční režim náhledu lze poznat ikonou lupy v levém dolním
          rohu.
        </Modal.Body>
        <Modal.Footer>
          <div className="flex space-x-4">
            <Button
              size="sm"
              text="Procházet web v režimu náhledu"
              style="primary"
              variant="primary"
              onClick={hidePreviewBar}
            />
            <Button
              size="sm"
              text="Odejít z režimu náhledu"
              style="red"
              variant="primary"
              link={{ url: "/api/exit-preview" }}
            />
          </div>
        </Modal.Footer>
      </Modal>
    </>
  );
};

export default PreviewBar;
