import { Fragment } from "react";

import { Articles } from "components/Articles";
import { BottomOverflow } from "components/BottomOverflow";
import { Button } from "components/Button";
import { Column } from "components/Column";
import { Columns } from "components/Columns";
import { ContactForm } from "components/ContactForm";
import { ContactSection } from "components/ContactSection";
import { Container } from "components/Container";
import { Divider } from "components/Divider";
import { Employees } from "components/Employees";
import { Faq } from "components/Faq";
import { Features } from "components/Features";
import { Gallery } from "components/Gallery";
import { Heading } from "components/Heading";
import { Hero } from "components/Hero";
import { Image } from "components/Image";
import { NumberedList } from "components/NumberedList";
import { OwlCarousel } from "components/OwlCarousel";
import { References } from "components/References";
import { RenderContent } from "components/RenderContent";
import { SectionImage } from "components/SectionImage";
import { Showcase } from "components/Showcase";
import { Timeline } from "components/Timeline";
import { Video } from "components/Video";

const RenderBlocks = ({ blocks }) => {
  const blockComponents = {
    container: Container,
    button: Button,
    contactForm: ContactForm,
    faq: Faq,
    contactSection: ContactSection,
    gallery: Gallery,
    numberedList: NumberedList,
    columns: Columns,
    column: Column,
    timeline: Timeline,
    sectionImage: SectionImage,
    heading: Heading,
    owlCarousel: OwlCarousel,
    content: RenderContent,
    articles: Articles,
    features: Features,
    showcase: Showcase,
    divider: Divider,
    hero: Hero,
    image: Image,
    bottomOverflow: BottomOverflow,
    employeesBlock: Employees,
    referenceBlock: References,
    videoBlock: Video,
  };

  const hasBlocks = blocks && Array.isArray(blocks) && blocks.length > 0;

  if (hasBlocks) {
    return (
      <Fragment>
        {blocks.map((block) => {
          const { blockType } = block;
          if (blockType) {
            const Block = blockComponents[blockType];
            if (Block) {
              return <Block {...block} key={block.id} />;
            } else {
              console.log("Block type not supported");
            }
          }
          return null;
        })}
      </Fragment>
    );
  }

  return null;
};

export default RenderBlocks;
