import Image from "next/image";

import { MARGIN_BOTTOM } from "styles/constants";

import { joinClassNames } from "utils/helper";

const Section = ({ data }: any) => {
  const {
    sections: { width, children },
    images,
    background,
    utilities,
  } = data;
  const { margin, id } = utilities || {};

  return (
    <div
      className={joinClassNames(
        "max-w-5xl px-4 lg:flex space-x-16 items-center mx-auto",
        MARGIN_BOTTOM[margin]
      )}
      id={id}
      style={{ backgroundImage: background ? background : "none" }}
    >
      <div className={joinClassNames("shrink-0", width)}>
        {children.map((item, index) => (
          <section className="mb-32 last:mb-0" key={index}>
            <h2 className="text-gray-800 text-5xl font-display mb-4">{item.title}</h2>
            <p className="text-gray-800 mb-4 text-justify">{item.description}</p>
          </section>
        ))}
      </div>
      <div>
        {images.map((item, index) => (
          <div className="mb-16 last:mb-0" key={index}>
            <Image
              src={item}
              width={item.width}
              height={item.height}
              alt={item.alt}
              className="w-full"
            />
          </div>
        ))}
      </div>
    </div>
  );
};

export default Section;
