import Image from "next/image";
import { Media, Page } from "payload-types";

import { MARGIN_BOTTOM } from "styles/constants";

import { createImageUrl, joinClassNames } from "utils/helper";

import { RenderBlocks } from "components/RenderBlocks";

type SectionImageBlock = Extract<
  Extract<Page["layout"][number], { blockType: "container" }>["layout"][number],
  { blockType: "sectionImage" }
>;

const SectionImage = ({
  buttons,
  children,
  image,
  id,
  marginBottom,
  setPriority,
}: SectionImageBlock) => {
  return (
    <div
      className={joinClassNames("max-w-6xl mx-auto", marginBottom && MARGIN_BOTTOM[marginBottom])}
      id={id}
    >
      <div className="relative">
        <div className="relative h-[16rem] sm:h-[20rem] md:h-[30rem] lg:h-[40rem]">
          <Image
            src={createImageUrl((image as Media).url)}
            alt={(image as Media).alt}
            className="rounded-xl fade w-full object-cover"
            sizes="(max-width: 768px) 100vw,
                (max-width: 1200px) 80vw,
                40vw"
            priority={setPriority}
            fill
          />
        </div>
        <div className="relative -mt-16 max-w-5xl gap-4 mx-auto px-2 ">
          <div className="flex items-start md:items-center flex-col md:flex-row justify-between">
            <RenderBlocks blocks={buttons} />
            <div className="mt-4 lg:mt-0 flex flex-col lg:flex-row font-display text-xl tracking-wider items-start lg:items-center justify-end gap-1">
              {children?.map((item, index) => (
                <div
                  className="flex items-center pr-4 lg:pl-4 first:pl-0 last:pr-0 text-gray-600"
                  key={index}
                >
                  <span className="block h-2 w-2 mr-4 rounded-full bg-primary-600"></span>
                  {item.title}
                </div>
              ))}
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default SectionImage;
