import Image from "next/image";
import { useEffect, useRef, useState } from "react";

const colors = ["/images/google.png", "/images/amazon.png", "/images/seznam.png"];
const delay = 2500;

function Slideshow() {
  const [index, setIndex] = useState(0);
  const timeoutRef = useRef(null);

  function resetTimeout() {
    if (timeoutRef.current) {
      clearTimeout(timeoutRef.current);
    }
  }

  useEffect(() => {
    resetTimeout();
    timeoutRef.current = setTimeout(
      () => setIndex((prevIndex) => (prevIndex === colors.length - 1 ? 0 : prevIndex + 1)),
      delay
    );

    return () => {
      resetTimeout();
    };
  }, [index]);

  return (
    <div className="mx-auto overflow-hidden max-w-5xl">
      <div
        className="whitespace-nowrap transition-transform duration-1000"
        style={{ transform: `translate3d(${-index * 100}%, 0, 0)` }}
      >
        {colors.map((backgroundColor, index) => (
          <div className="relative h-[400px] bg-primary-700 w-full inline-block" key={index}>
            <Image
              src={backgroundColor}
              className="w-[312px] absolute top-1/2 -translate-y-1/2 left-1/2 -translate-x-1/2 filter grayscale"
              alt="Background"
            />
          </div>
        ))}
      </div>

      <div className="flex space-x-2 mt-2">
        {colors.map((_, idx) => (
          <div
            className="relative h-5 w-5 bg-primary-500 rounded-full"
            onClick={() => {
              setIndex(idx);
            }}
            key={idx}
          >
            {index === idx && (
              <div className="absolute h-2.5 w-2.5 bg-white left-1/2 -translate-x-1/2 top-1/2 -translate-y-1/2 rounded-full" />
            )}
          </div>
        ))}
      </div>
    </div>
  );
}

export default Slideshow;
