import { NextApiRequest, NextApiResponse } from "next";
import { Page } from "payload-types";
import { fetchWebsiteSettings } from "queries/globals";
import { fetchPage } from "queries/pages";
import { fetchPost } from "queries/posts";

function redirectToPreview(res: NextApiResponse, Location: string) {
  res.setPreviewData({});
  res.writeHead(307, { Location });
  res.end();
}

export default async function preview(req: NextApiRequest, res: NextApiResponse) {
  const secret = process.env.PAYLOAD_PRIVATE_NEXTJS_PREVIEW_KEY;

  if (secret && req.query.secret !== secret) {
    return res.status(401).json({ message: "Invalid secret" });
  }
  let url: string;
  if (req.query.collection === "pages") {
    const websiteSettings = await fetchWebsiteSettings();

    if (req.query.slug === (websiteSettings.mainPage.value as Page).slug) {
      return redirectToPreview(res, "/");
    }

    const page = await fetchPage(req.query.slug as string, false);

    if (!page) {
      return res.status(401).json({ message: "Invalid slug" });
    }

    url = `/${page.slug}`;
  } else {
    const post = await fetchPost(req.query.slug as string, false);

    if (!post) {
      return res.status(401).json({ message: "Invalid slug" });
    }

    url = `/blog/${post.slug}`;
  }

  redirectToPreview(res, url);
}
