import type { NextApiRequest, NextApiResponse } from "next";
import nodemailer from "nodemailer";

import responses from "utils/responses";

const handler = async (req: NextApiRequest, res: NextApiResponse) => {
  await new Promise(async (resolve) => {
    try {
      if (req.method === "POST") {
        const { name, email, subject, message } = req.body;

        const response = await fetch("https://www.google.com/recaptcha/api/siteverify", {
          method: "POST",
          headers: {
            "Content-Type": "application/x-www-form-urlencoded",
          },
          body: `secret=${process.env.RECAPTCHA_SECRET_KEY}&response=${req.body.gRecaptchaToken}`,
        });
        const captcha = await response.json();

        // Low captcha score, probably bot
        if (captcha.score < 0.5) {
          res.status(500).json({
            status: "failure",
            message: responses.failure.failedToVerifyRecaptcha,
          });
          return resolve("Low captcha score");
        }

        // Create transport
        const transporter = nodemailer.createTransport({
          port: 465,
          host: process.env.SMTP_HOST,
          auth: {
            user: process.env.SMTP_USER,
            pass: process.env.SMTP_PASS,
          },
          secure: true,
        });

        // Prepare email data
        const data = {
          from: "no-reply@energosavings.cz",
          to: "info@energosavings.cz",
          subject: subject,
          replyTo: email,
          text: `${name} (e-mailová adresa: ${email}) zaslal/a tuto zprávu přes kontaktní formulář na webu: ${message}.`,
        };

        transporter.sendMail(data, function (err, info) {
          if (err) {
            console.log(err);
            res.status(500).json({
              status: "failure",
              message: responses.failure.failedToSendEmail,
            });
            return resolve(err);
          } else {
            res.status(200).json({
              status: "success",
              message: responses.success.emailSent,
            });
            return resolve(info);
          }
        });
      } else {
        res.status(405);
        res.end();
      }
    } catch (err) {
      res.status(405).json({
        status: "failure",
        message: responses.failure.failedToProcessForm,
      });
    }
  });
};

export default handler;
