import { GetServerSideProps } from "next";
import { getServerSideSitemap } from "next-sitemap";
import { Employee, Page, Post } from "payload-types";
import { fetchWebsiteSettings } from "queries/globals";

export default function Sitemap() {}

export const getServerSideProps: GetServerSideProps = async (ctx) => {
  const websiteSettings = await fetchWebsiteSettings();
  const homepage = websiteSettings.mainPage.value as Page;

  let paths = [];
  const pages = await fetch(`${process.env.NEXT_PUBLIC_CMS_URL}/api/pages/all`)
    .then((res) => res.json())
    .then((pages) =>
      pages.map((page: Page) => {
        if (page.slug === homepage.slug) {
          page.slug = "";
        }
        return page;
      })
    );
  const posts = await fetch(`${process.env.NEXT_PUBLIC_CMS_URL}/api/posts/all`)
    .then((res) => res.json())
    .then((posts) => posts.map((post: Post) => ({ ...post, slug: `blog/${post.slug}` })));

  const employees = await fetch(`${process.env.NEXT_PUBLIC_CMS_URL}/api/employees/all`)
    .then((res) => res.json())
    .then((employees) =>
      employees.map((employee: Employee) => ({ ...employee, slug: `employee/${employee.slug}` }))
    );

  paths = pages.concat(posts, employees);

  const sitemap = paths.map((post) => {
    return {
      loc: `${process.env.SITE_URL}/${post.slug}`,
      lastmod: post.updatedAt,
    };
  });
  return await getServerSideSitemap(ctx, sitemap);
};
