import { marginBottom } from "../fields/marginBottom";
import type { Block } from "payload/types";

export const Articles: Block = {
  slug: "articles",
  labels: {
    singular: "Články",
    plural: "Články",
  },
  fields: [
    {
      name: "perPage",
      label: "Počet článků na stránku",
      min: 2,
      max: 12,
      type: "number",
      required: true,
      admin: {
        step: 1,
      },
    },
    {
      name: "categories",
      label: "Kategorie",
      admin: {
        description:
          "Vyber kategorie - poté se budou zobrazovat pouze články, které tuto kategorii mají",
      },
      type: "relationship",
      relationTo: ["categories"],
      hasMany: true,
    },
    {
      name: "articles",
      label: "Články",
      type: "json",
      admin: {
        disabled: true,
      },
      hooks: {
        afterRead: [
          async ({ req, siblingData }) => {
            const categories = siblingData.categories;
            const { docs } = await req.payload.find({
              collection: "posts",
              pagination: false,
            });
            return docs;
          },
        ],
      },
    },
    marginBottom(),
  ],
};
