import colorField from "../fields/colorPicker/config";
import { marginBottom } from "../fields/marginBottom";
import { marginTop } from "../fields/marginTop";
import { textAlign } from "../fields/textAlign";
import type { Block } from "payload/types";

export const Heading: Block = {
  slug: "heading",
  labels: {
    singular: "Nadpis",
    plural: "Nadpisy",
  },
  fields: [
    {
      name: "text",
      label: "Text nadpisu",
      type: "text",
      required: true,
    },
    {
      name: "as",
      label: "HTML značka nadpisu",
      type: "radio",
      options: [
        {
          label: "Obyčejný text",
          value: "p",
        },
        {
          label: "Nadpis první úrovně",
          value: "h1",
        },
        {
          label: "Nadpis druhé úrovně",
          value: "h2",
        },
        {
          label: "Nadpis třetí úrovně",
          value: "h3",
        },
        {
          label: "Nadpis čtvrté úrovně",
          value: "h4",
        },
        {
          label: "Nadpis páté úrovně",
          value: "h5",
        },
        {
          label: "Nadpis šesté úrovně",
          value: "h6",
        },
      ],
      defaultValue: "p",
      admin: {
        layout: "horizontal",
        description:
          "HTML značka slouží k lepší strukturalizaci obsahu pro webové prohlížeče a vyhledávače. Nadpisy by měly být seřazeny postupně, aby obsah dával smysl. Pokud nevíte, jakou značku vybrat, vyberte standardní 'p' značku.",
      },
    },
    {
      name: "type",
      label: "Typ nadpisu",
      type: "radio",
      options: [
        {
          label: "Nadpis první úrovně",
          value: "h1",
        },
        {
          label: "Nadpis druhé úrovně",
          value: "h2",
        },
        {
          label: "Nadpis třetí úrovně",
          value: "h3",
        },
        {
          label: "Nadpis čtvrté úrovně",
          value: "h4",
        },
        {
          label: "Nadpis páté úrovně",
          value: "h5",
        },
        {
          label: "Nadpis šesté úrovně",
          value: "h6",
        },
      ],
      defaultValue: "base",
      admin: {
        layout: "horizontal",
        description: "Typ nadpisu mění vzhled nadpisu.",
      },
    },
    colorField,
    marginBottom(),
    marginTop(),
    textAlign(),
  ],
};
