import { Container } from "../blocks/Container";
import { slugField } from "../fields/slug";
import { regeneratePage } from "../utilities/regeneratePage";
import { CollectionConfig } from "payload/types";

const Employees: CollectionConfig = {
  slug: "employees",
  admin: {
    useAsTitle: "name",
  },
  labels: {
    singular: "Zaměstnanec",
    plural: "Zaměstnanci",
  },
  access: {
    read: () => {
      return true;
    },
  },
  hooks: {
    afterChange: [
      ({ req: { payload } }) => {
        regeneratePage({
          payload,
        });
      },
    ],
  },
  fields: [
    {
      name: "name",
      label: "Jméno",
      type: "text",
      required: true,
    },
    {
      name: "showEmployee",
      label: "Zobrazit zaměstnance",
      type: "checkbox",
      defaultValue: false,
    },
    {
      name: "mainEmployee",
      label: "Hlavní zaměstnanec",
      admin: {
        description:
          "Zobrazuje se na stránce primárně před ostatními zaměstnanci",
      },
      type: "checkbox",
      defaultValue: false,
    },
    {
      name: "telephoneNumber",
      label: "Telefonní číslo",
      type: "text",
    },
    {
      name: "position",
      label: "Pozice",
      type: "text",
    },
    {
      name: "email",
      label: "E-mailová adresa",
      type: "text",
      required: true,
    },
    {
      name: "image",
      type: "upload",
      relationTo: "media",
    },
    {
      label: "Komponenta",
      labels: {
        singular: "Komponenta",
        plural: "Komponenty",
      },
      name: "layout",
      type: "blocks",
      blocks: [Container],
    },
    slugField("name", { required: true }),
  ],
  endpoints: [
    {
      path: "/slugs",
      method: "get",
      handler: async (req, res, next) => {
        const { docs } = await req.payload.find({
          collection: "employees",
          pagination: false,
        });
        const slugs = docs.map((post) => post.slug);
        if (docs) {
          res.status(200).send(slugs);
        } else {
          res.status(404).send({ error: "not found" });
        }
      },
    },
    {
      path: "/all",
      method: "get",
      handler: async (req, res) => {
        const { docs } = await req.payload.find({
          collection: "employees",
          pagination: false,
        });
        if (docs) {
          res.status(200).send(docs);
        } else {
          res.status(404).send({ error: "not found" });
        }
      },
    },
  ],
};

export default Employees;
