import deepMerge from "../utilities/deepMerge";
import { Field } from "payload/types";

export const appearanceOptions = {
  text: {
    label: "Text",
    value: "text",
  },
  primaryButton: {
    label: "Primary Button",
    value: "primaryButton",
  },
  secondaryButton: {
    label: "Secondary Button",
    value: "secondaryButton",
  },
};

type LinkType = (options?: {
  appearances?: string[] | false;
  disableLabel?: boolean;
  disableIcon?: boolean;
  overrides?: Record<string, unknown>;
}) => Field;

const link: LinkType = ({
  appearances,
  disableLabel = false,
  disableIcon = false,
  overrides = {},
} = {}) => {
  const generatedLink: Field = {
    name: "link",
    label: "Odkaz",
    type: "group",
    fields: [
      {
        name: "type",
        label: "Typ",
        type: "radio",
        options: [
          {
            label: "Interní odkaz",
            value: "reference",
          },
          {
            label: "Vlastní adresa URL",
            value: "custom",
          },
        ],
        defaultValue: "reference",
        admin: {
          layout: "horizontal",
        },
      },
    ],
  };

  const linkOptions: Field = {
    type: "row",
    fields: [
      {
        name: "reference",
        label: "Dokument na který odkazovat",
        type: "relationship",
        relationTo: ["pages", "posts"],
        maxDepth: 1,
        required: true,
        admin: {
          condition: (_, siblingData) => siblingData?.type === "reference",
        },
      },
      {
        name: "url",
        label: "Vlastní URL adresa",
        type: "text",
        required: true,
        admin: {
          condition: (_, siblingData) => siblingData?.type === "custom",
        },
      },
    ],
  };

  if (!disableLabel) {
    linkOptions.fields.unshift({
      name: "label",
      label: "Název odkazu",
      type: "text",
      required: true,
      admin: {
        width: "50%",
      },
    });

    linkOptions.fields[1].admin.width = "50%";
    linkOptions.fields[2].admin.width = "50%";
    generatedLink.fields[0].admin.width = "50%";
    generatedLink.fields.push(linkOptions);
  } else {
    generatedLink.fields.push(linkOptions);
  }

  generatedLink.fields.push({
    name: "newTab",
    label: "Otevřít na nové kartě",
    type: "checkbox",
  });

  if (!disableIcon) {
    generatedLink.fields.push({
      name: "icon",
      label: "Ikona",
      type: "upload",
      relationTo: "media",
      maxDepth: 1,
    });
  }

  // Use all appearances by default
  if (typeof appearances === "undefined") {
    generatedLink.fields.unshift({
      name: "appearance",
      type: "select",
      defaultValue: "text",
      options: [
        appearanceOptions.text,
        appearanceOptions.primaryButton,
        appearanceOptions.secondaryButton,
      ],
    });
  }

  // Manually select appearances
  if (appearances) {
    generatedLink.fields.unshift({
      name: "appearance",
      type: "select",
      defaultValue: appearances[0],
      options: appearances.map((appearance) => appearanceOptions[appearance]),
    });
  }

  return deepMerge(generatedLink, overrides);
};

export default link;
