import { regeneratePage } from "../utilities/regeneratePage";
import { GlobalConfig } from "payload/types";

const Metadata: GlobalConfig = {
  slug: "metadata",
  label: "Metadata",
  access: {
    read: () => true,
  },
  hooks: {
    afterChange: [
      ({ req: { payload } }) => {
        regeneratePage({
          payload,
        });
      },
    ],
  },
  fields: [
    {
      name: "defaultTitle",
      label: "Výchozí název webu",
      admin: {
        description:
          "Výchozí název webu, který se bude zobrazovat v metadatech stránky.",
      },
      type: "text",
      required: true,
    },
    {
      name: "ogDescription",
      label: "Popis webu",
      admin: {
        description:
          "Popis webu (společnosti), který se bude zobrazovat na sociálních sítích",
      },
      type: "text",
      required: true,
    },
    {
      name: "ogTwitter",
      label: "Twitter uživatelské jméno",
      admin: {
        description: "Uživatelské jméno na Twitteru ve formátu @jmeno",
      },
      type: "text",
      required: true,
    },
    {
      name: "ogCreator",
      label: "Twitter uživatelské jméno tvůrce",
      admin: {
        description: "Uživatelské jméno na Twitteru ve formátu @jmeno",
      },
      type: "text",
      required: true,
    },
    {
      name: "ogImage",
      label: "Náhledový obrázek",
      admin: {
        description:
          "Náhledový obrázek, který se bude zobrazovat v příspěvcích na sociálních sítích (velikost obrázku doporučena 1200 X 630 pixelů)",
      },
      type: "upload",
      relationTo: "media",
      required: true,
    },
  ],
};

export default Metadata;
