import { Categories } from "./collections/Categories";
import { ClientReferences } from "./collections/ClientReferences";
import { Clients } from "./collections/Clients";
import Documents from "./collections/Documents";
import Employees from "./collections/Employees";
import Media from "./collections/Media";
import { Pages } from "./collections/Pages";
import { Posts } from "./collections/Posts";
import Users from "./collections/Users";
import Videos from "./collections/Videos";
import AfterDashboard from "./components/AfterDashboard";
import BeforeDashboard from "./components/BeforeDashboard";
import ContactDetails from "./globals/ContactDetails";
import Cookies from "./globals/Cookies";
import { Footer } from "./globals/Footer";
import Header from "./globals/Header";
import Metadata from "./globals/Metadata";
import SocialSites from "./globals/SocialSites";
import WebsiteSettings from "./globals/WebsiteSettings";
import { Icon } from "./graphics/Icon";
import { Logo } from "./graphics/Logo";
import seo from "@payloadcms/plugin-seo";
import dotenv from "dotenv";
import path from "path";
import { buildConfig } from "payload/config";
import { Document } from "payload/types";

dotenv.config({
  path: path.resolve(__dirname, "../.env"),
});

export default buildConfig({
  serverURL: process.env.PAYLOAD_PUBLIC_SERVER_URL,
  admin: {
    user: Users.slug,
    meta: {
      titleSuffix: "- Energosavings",
      favicon: "/assets/favicon.svg",
      ogImage: "/assets/logo.svg",
    },
    components: {
      beforeDashboard: [BeforeDashboard],
      afterDashboard: [AfterDashboard],
      graphics: {
        Logo,
        Icon,
      },
    },
    css: path.resolve(__dirname, "./styles/custom.scss"),
  },
  cors: "*",
  maxDepth: 4,
  rateLimit: {
    trustProxy: true,
    max: 5000,
  },
  plugins: [
    seo({
      collections: ["pages", "posts"],
      generateTitle: ({ doc }: { doc: Document }) => {
        return `Energo Savings - ${doc.title.value}`;
      },
    }),
  ],
  defaultDepth: 4,
  collections: [
    Users,
    Pages,
    Posts,
    Categories,
    ClientReferences,
    Media,
    Employees,
    Documents,
    Videos,
    Clients,
  ],
  globals: [
    Header,
    Footer,
    SocialSites,
    Metadata,
    ContactDetails,
    WebsiteSettings,
    Cookies,
  ],
  upload: {
    limits: {
      fileSize: 100000000, // 100MB, written in bytes
    },
  },
  typescript: {
    outputFile: path.resolve(__dirname, "../payload-types.ts"),
  },
  graphQL: {
    schemaOutputFile: path.resolve(__dirname, "generated-schema.graphql"),
  },
});
